==> owncloud-10.2.0.zip: owncloud/apps/federatedfilesharing/l10n/tr.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Birleşmiş paylaşım",
    "Invalid Federated Cloud ID" : "Geçersiz Birleşmiş Bulut Kimliği",
    "Sharing %s failed, because this item is already shared with %s" : "%s paylaşımı, %s ile zaten paylaşıldığından dolayı başarısız oldu",
    "Not allowed to create a federated share with the same user" : "Aynı kullanıcı ile bir birleşmiş paylaşım oluşturulamaz",
    "File is already shared with %s" : "Dosya önceden %s ile paylaşıldı",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s paylaşımı başarısız. %s bulunamadı veya sunucu şu anda ulaşılamıyor olabilir.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "%1$s kişisinden \"/%3$s\" uzak paylaşımını aldınız (%2$s adına)",
    "You received \"/%3$s\" as a remote share from %1$s" : "%1$s kişisinden \"/%3$s\" uzak paylaşımını aldınız",
    "Accept" : "Kabul et",
    "Decline" : "Reddet",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "#ownCloud Birleşmiş Bulut kimliğim ile paylaş, bkz %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "#ownCloud Birleşmiş Bulut kimliğim ile paylaş",
    "Federated Cloud Sharing" : "Birleşmiş Bulut Paylaşımı",
    "Open documentation" : "Belgelendirmeyi aç",
    "Allow users on this server to send shares to other servers" : "Bu sunucudaki kullanıcıların diğer sunuculara paylaşım göndermelerine izin ver",
    "Allow users on this server to receive shares from other servers" : "Bu sunucudaki kullanıcıların diğer sunuculardan paylaşım almalarına izin ver",
    "Federated Cloud" : "Birleşmiş Bulut",
    "Your Federated Cloud ID:" : "Birleşmiş Bulut Kimliğiniz:",
    "Share it:" : "Paylaşın:",
    "Add to your website" : "Web sitenize ekleyin",
    "Share with me via ownCloud" : "Benimle ownCloud aracılığıyla paylaşın",
    "HTML Code:" : "HTML Kodu:",
    "Add to your ownCloud" : "ownCloud'ınıza Ekleyin"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-10.4.0.zip: owncloud/apps/federatedfilesharing/l10n/tr.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Birleşmiş paylaşım",
    "Add to your ownCloud" : "ownCloud'ınıza ekleyin",
    "Invalid Federated Cloud ID" : "Geçersiz Birleşmiş Bulut Kimliği",
    "Sharing %s failed, because this item is already shared with %s" : "%s paylaşımı, %s ile zaten paylaşıldığından dolayı başarısız oldu",
    "Not allowed to create a federated share with the same user" : "Aynı kullanıcı ile bir birleşmiş paylaşım oluşturulamaz",
    "File is already shared with %s" : "Dosya önceden %s ile paylaşıldı",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s paylaşımı başarısız. %s bulunamadı veya sunucu şu anda ulaşılamıyor olabilir.",
    "Federated Sharing failed: %s" : "Birleşmiş Paylaşımda hata: %s",
    "\"%1$s\" shared \"%3$s\" with you (on behalf of \"%2$s\")" : "\"%1$s\" seninle \"%3$s\" paylaştı (\"%2$s\" adına)",
    "\"%1$s\" shared \"%3$s\" with you" : "\"%1$s\" seninle \"%3$s\" paylaştı",
    "\"%1$s\" invited you to view \"%3$s\" (on behalf of \"%2$s\")" : "\"%1$s\" seni \"%3$s\" görüntülemeye davet etti (\"%2$s\" adına)",
    "\"%1$s\" invited you to view \"%3$s\"" : "\"%1$s\" seni \"%3$s\" görüntülemeye davet etti",
    "Accept" : "Kabul et",
    "Decline" : "Reddet",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "#ownCloud Birleşmiş Bulut kimliğim ile paylaş, bkz %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "#ownCloud Birleşmiş Bulut kimliğim ile paylaş",
    "Federated Cloud Sharing" : "Birleşmiş Bulut Paylaşımı",
    "Open documentation" : "Belgelendirmeyi aç",
    "Allow users on this server to send shares to other servers" : "Bu sunucudaki kullanıcıların diğer sunuculara paylaşım göndermelerine izin ver",
    "Allow users on this server to receive shares from other servers" : "Bu sunucudaki kullanıcıların diğer sunuculardan paylaşım almalarına izin ver",
    "Automatically accept remote shares from trusted servers" : "Güvenilir sunuculardan gelen uzak paylaşımları otomatik olarak kabul et",
    "Federated Cloud" : "Birleşmiş Bulut",
    "Your Federated Cloud ID:" : "Birleşmiş Bulut Kimliğiniz:",
    "Share it:" : "Paylaşın:",
    "Add to your website" : "Web sitenize ekleyin",
    "Share with me via ownCloud" : "Benimle ownCloud aracılığıyla paylaşın",
    "HTML Code:" : "HTML Kodu:",
    "Nothing to configure." : "Yapılandırılacak birşey yok."
},
"nplurals=2; plural=(n > 1);");
